@@ -11,8 +11,7 @@
 #' industry or product names for matching, for example the employment coefficients. 
 #' @param Im A Leontieff-inverse with a key column containing the industry or 
 #' product names for matching.
-#' @importFrom magrittr %>%
-#' @importFrom dplyr filter select mutate left_join mutate_if
+#' @importFrom dplyr select mutate mutate_if full_join
 #' @importFrom tidyr spread
 #' @examples
 #' Im = data.frame (
@@ -32,29 +31,32 @@ equation_solve <- function ( LHS = NULL, Im = NULL ) {
       "Error: matrix equation inputs are not given.")
 
   LHS <- LHS %>%
-    mutate_if (is.factor, as.character) 
+    dplyr::mutate_if (is.factor, as.character) 
   Im <- Im %>%
-    mutate_if (is.factor, as.character) 
+    dplyr::mutate_if (is.factor, as.character) 
   
   if ( ncol (Im) < ncol(LHS)) {
+    
    not_found <-  names(LHS)[ which (! names(LHS) %in% names ( Im )) ]
-   if ( all ( not_found %in% c("CPA_T", "CPA_U", "CPA_L68A", "TOTAL", "CPA_TOTAL"))) {
+   
+   if ( all ( not_found %in% c("CPA_T", "CPA_U", "CPA_L68A",
+                               "TOTAL", "CPA_TOTAL"))) {
      warning ( paste ( not_found, collapse = ','),  
-' from the input vector is removed. These are likely zero values, 
-and cannot be found in the Leontieff-inverse.'
-)
-     LHS <- dplyr::select ( LHS, -dplyr::one_of ( not_found ))
-   } else if  ( any( not_found  %in%  c("households", "P3_S14"))  )  {
-        stop ("The input vector has households but the Leontieff-inverse has not.")
+                ' from the input vector is removed. These are likely zero values, 
+               and cannot be found in the Leontieff-inverse.'
+              )
+     LHS <- dplyr::select ( LHS, -dplyr::one_of ( not_found ) )   
+     } else if  ( any( not_found  %in%  c("households", "P3_S14"))  )  {
+       stop ("The input vector has households but the Leontieff-inverse has not.")
      } else {
-     stop ("Non confirming input vector and Leontieff-inverse.")
+     stop ("Non conforming input vector and Leontieff-inverse.")
    }
   }
 
   ###Joining matrixes to find out if all data is present ---------------------   
 
   joined <- tryCatch(
-      full_join (LHS, Im, by = names(LHS)), 
+      dplyr::full_join (LHS, Im, by = names(LHS)), 
       error = function(e) {
         message ( "The technology columns are not matching.")
         return (NULL)
