@@ -3,13 +3,7 @@ library (iotables)
 require (dplyr)
 context ("Creating an  output coefficient matrix")
 
-io_table <- iotable_get () 
-io_table <- io_table [1:which(tolower(io_table[,1]) =="total" ), ]
-
-output_bp <- dplyr::select ( io_table, output_bp )
-io_table <- io_table [, 1:7] 
-io_table$total <- rowSums(io_table[, 2:7])
-io_table <- cbind (io_table, output_bp)
+io_table <- iotable_get ( )
 
 test_that("wrong paramter error", {
   expect_error(output_coefficient_matrix_create (
@@ -17,6 +11,7 @@ test_that("wrong paramter error", {
   })
 
 
+
 output_coefficients <- output_coefficient_matrix_create (
                            io_table, "final_demand", digits = 4)
 
